@@ -7,12 +7,12 @@
 #include "dbconsole.h"
 #include <Akonadi/DbAccess>
 
+#include <KStandardActions>
 #include <QAction>
 
 #include <KConfigGroup>
 #include <KLocalizedString>
 #include <KSharedConfig>
-#include <KStandardAction>
 #include <QIcon>
 
 #include <QApplication>
@@ -86,7 +86,7 @@ DbConsoleTab::DbConsoleTab(int index, QWidget *parent)
 {
     ui.setupUi(this);
 
-    QAction *copyAction = KStandardAction::copy(this, &DbConsoleTab::copyCell, this);
+    QAction *copyAction = KStandardActions::copy(this, &DbConsoleTab::copyCell, this);
     ui.resultView->addAction(copyAction);
 
     ui.execButton->setIcon(QIcon::fromTheme(QStringLiteral("application-x-executable")));
