@@ -15,7 +15,10 @@ class DebugModel : public QAbstractItemModel
 {
     Q_OBJECT
 public:
-    enum Direction { ClientToServer, ServerToClient };
+    enum Direction {
+        ClientToServer,
+        ServerToClient
+    };
 
     struct Message {
         QString sender;
@@ -23,7 +26,10 @@ public:
         QString message;
     };
 
-    enum Roles { MessageRole = Qt::UserRole, IdentifierRole };
+    enum Roles {
+        MessageRole = Qt::UserRole,
+        IdentifierRole
+    };
 
     enum Columns {
         DirectionColumn,
