@@ -8,7 +8,7 @@
 #include "akonadiconsole_debug.h"
 #include "loggingmodel.h"
 
-#include <KCheckComboBox>
+#include <Libkdepim/KCheckComboBox>
 #ifndef COMPILE_WITH_UNITY_CMAKE_SUPPORT
 Q_DECLARE_METATYPE(LoggingModel::Message)
 #endif
@@ -25,9 +25,7 @@ LoggingFilterModel::LoggingFilterModel(QObject *parent)
     connect(&mInvalidateTimer, &QTimer::timeout, this, &LoggingFilterModel::invalidate);
 }
 
-LoggingFilterModel::~LoggingFilterModel()
-{
-}
+LoggingFilterModel::~LoggingFilterModel() = default;
 
 void LoggingFilterModel::setAppFilter(KCheckComboBox *appFilter)
 {
@@ -89,3 +87,5 @@ bool LoggingFilterModel::filterAcceptsRow(int source_row, const QModelIndex &) c
     const auto msg = sourceModel()->data(source_idx, LoggingModel::MessageRole).value<LoggingModel::Message>();
     return mCheckedApps.contains(msg.app) && mCheckedCategories.contains(msg.category) && mCheckedTypes.contains(msg.type);
 }
+
+#include "moc_loggingfiltermodel.cpp"
