@@ -199,8 +199,23 @@ void NotificationMonitor::populateItemNtfTree(QStandardItemModel *model, const A
     appendRow(model, i18n("Item Parts"), toString(ntf.itemParts()));
     appendRow(model, i18n("Added Flags"), toString(ntf.addedFlags()));
     appendRow(model, i18n("Removed Flags"), toString(ntf.removedFlags()));
-    appendRow(model, i18n("Added Tags"), toString(ntf.addedTags()));
-    appendRow(model, i18n("Removed Tags"), toString(ntf.removedTags()));
+
+    {
+        QSet<qint64> set;
+        std::ranges::transform(ntf.addedTags(), std::inserter(set, set.begin()), [](const auto &tagResponse) -> Akonadi::Tag::Id {
+            return tagResponse.id();
+        });
+        appendRow(model, i18n("Added Tags"), toString(set));
+    }
+
+    {
+        QSet<qint64> set;
+        std::ranges::transform(ntf.removedTags(), std::inserter(set, set.begin()), [](const auto &tagResponse) -> Akonadi::Tag::Id {
+            return tagResponse.id();
+        });
+        appendRow(model, i18n("Removed Tags"), toString(set));
+    }
+
     appendRow(model, i18n("Must retrieve"), toString(ntf.mustRetrieve()));
 
     auto itemsItem = new QStandardItem(i18n("Items"));
